import { DataType } from '../types';
/**
 * TypeUtil util class.
 *
 * @export
 * @class TypeUtil
 */
export declare class TypeUtil {
    /**
     * Array that holds the number types
     *
     * @private
     * @type {string[]}
     * @memberof TypeUtil
     */
    private numberTypes;
    /**
     * Array that holds the string types
     *
     * @private
     * @type {string[]}
     * @memberof TypeUtil
     */
    private stringTypes;
    /**
     * Converts a given database type to the standard one.
     * @param {string} type db type.
     * @returns {string} standard type
     */
    convertSqlType(type: string): string;
    /**
     * Converts no sql types to standard schema
     * @param {string} type - type to be converted
     */
    convertNoSqlType(type: string): void;
    /**
     * Converts raml types to standard schema
     * @param {{type: string; items: string}} type - type to be converted
     * @returns {{type: string; isArray: boolean; values?: string[]}} - converted type
     */
    convertRamlTypes(type: {
        type: string;
        items: string;
    }): DataType;
    /**
     * Converts Enum values to string.
     *
     * @param {DataType} type source datatype
     * @return {string} enum values as string
     */
    getEnumValuesAsString(type: DataType): string;
    /**
     * Checks if the provided type is a default one.
     *
     * @param {string} type - data type
     * @return {boolean} returns true if type is a default one.
     */
    isDefaultType(type: string): boolean;
}
declare const _default: TypeUtil;
export default _default;
