import { PackageJson, PackageJsonInfo } from '../../commons/types';
/**
 * Class which implements the logic for generating valid package.json files.
 *
 * @export
 * @class PackageJsonGenerator
 */
export declare class PackageJsonGenerator {
    /**
     * Generates content of package json
     *
     * @param {PackageJsonInfo} options - package json info
     * @param {string} dialect - database types
     * @returns {PackageJson} - package json content
     * @memberof PackageJsonGenerator
     */
    getPackageJson(options: PackageJsonInfo, dialect: string): PackageJson;
    /**
     * Generate package.json as string
     *
     * @param {PackageJsonInfo} options - package json info
     * @param {string} dialect - database type
     * @returns {string} - package json as string
     * @memberof PackageJsonGenerator
     */
    getPackageJsonAsString(options: PackageJsonInfo, dialect: string): string;
    /**
     * Based on database type generates some helpfull scripts for it
     *
     * @private
     * @param {string} databaseType - database type
     * @returns {MapOfStrings} - map of helpull scripts
     * @memberof PackageJsonGenerator
     */
    private getScriptsForDb(databaseType);
}
declare const _default: PackageJsonGenerator;
export default _default;
