import { Schema, Table, RAMLApplicationInfo } from '../../commons/types';
/**
 * Class which holds the logic for generating raml spec.
 *
 * @export
 * @class SpecGenerator
 */
export declare class SpecGenerator {
    /**
     * Generates the api spec for the whole schema.
     *
     * @param {Schema} schema - entire collection of tables
     * @param {RAMLApplicationInfo} options - holds the title of the app, the version and the base url
     * @return {string} - returns the api spec
     */
    generateContent(schema: Schema, options: RAMLApplicationInfo): string;
    /**
     * Generates the header content
     *
     * @param {RAMLApplicationInfo} options - holds the title of the app, the version and the base url
     * @return {string} returns the formatted header
     */
    addHeaderContent(options: RAMLApplicationInfo): string;
    /**
     * Adds the data types based on schema
     *
     * @param {Schema} schema - entire collection of tables
     * @return {string} returns the formatted data types
     */
    addDataTypes(schema: Schema): string;
    /**
     * Generates the get all spec
     *
     * @param {Table} entity - holds the entity definition
     * @return {string} - returns the formatted spec for the entity
     */
    addSpecForEntity(entity: Table): string;
    /**
     * Generates the get all spec
     *
     * @param {string} initialIndentation - holds the initial indentation
     * @param {Table} entity - holds the entity definition
     * @return {string} - returns the formatted get all spec
     */
    addGetAllSpec(initialIndentation: string, entity: Table): string;
    /**
     * Generates the create spec
     *
     * @param {string} initialIndentation - holds the initial indentation
     * @param {Table} entity - holds the entity definition
     * @return {string} - returns the formatted create spec
     */
    addCreateSpec(initialIndentation: string, entity: Table): string;
    /**
     * Generates the get one spec
     *
     * @param {string} initialIndentation - holds the initial indentation
     * @param {Table} entity - holds the entity definition
     * @return {string} - returns the formatted get one spec
     */
    addGetOneSpec(initialIndentation: string, entity: Table): string;
    /**
     * Generates the update spec
     *
     * @param {string} initialIndentation - holds the initial indentation
     * @param {Table} entity - holds the entity definition
     * @return {string} - returns the formatted update spec
     */
    addUpdateSpec(initialIndentation: string, entity: Table): string;
    /**
     * Generates the delete spec
     *
     * @param {string} initialIndentation - holds the initial indentation
     * @param {Table} entity - holds the entity definition
     * @return {string} - returns the formatted delete spec
     */
    addDeleteSpec(initialIndentation: string, entity: Table): string;
}
declare const _default: SpecGenerator;
export default _default;
