import * as mysql from 'mysql';
import BaseHandler from './BaseHandler';
import { Schema, Table, TableReference } from '../commons/types';
/**
 * MySql Handler.
 *
 * @export
 * @class MysqlHandler
 * @extends {BaseHandler}
 */
export default class MysqlHandler extends BaseHandler {
    /**
     * Mysql connection object.
     *
     * @private
     * @type {mysql.Connection}
     * @memberof MysqlHandler
     */
    private connection;
    /**
     * Mysql connection options
     *
     * @private
     * @type {mysql.IConnectionConfig}
     * @memberof MysqlHandler
     */
    private options;
    /**
     * Constructor for the MySqlHandler.
     *
     * @param {mysq.IConnectionConfig} options Connection parameters.
     */
    constructor(options: mysql.IConnectionConfig);
    /**
     * Connect to MySql based on the connection data.
     */
    connect(): void;
    /**
     * Reads the database schema, processes it and returns a normalized version of it.
     *
     * @returns {Promise<Schema>} database schema
     */
    readSchema(): Promise<Schema>;
    /**
     * Reads the information schema and returns an array of tables.
     *
     * @returns {Promise<string[]>} array of table names.
     */
    getTables(): Promise<string[]>;
    /**
     * Reads the schema for a given table.
     *
     * @param {string} tableName table name
     * @returns {Promise<Table>} table schema
     */
    getTableSchema(tableName: string): Promise<Table>;
    /**
     * Reads all the relations for a given table.
     *
     * @param {string} table table name
     * @return {Promise<TableReference[]>} foreign key relations
     */
    getRelationsForTable(table: string): Promise<TableReference[]>;
    /**
     * Closes the MySql connection.
     */
    close(): void;
}
