import { RamlColumnSchema, Column, Schema } from '../commons/types';
/**
 * Raml schema pre processor.
 *
 * @export
 * @class RamlSchemaPreprocessor
 */
export default class RamlSchemaPreprocessor {
    /**
     * Normalize the table schema.
     *
     * @param {RamlColumnSchema} columnSchema column schema to be normalized
     * @returns {Column} normalized column schema
     */
    convertToStandardSchema(columnSchema: RamlColumnSchema): Column;
    /**
     * Normalize schema relations.
     *
     * @param {Schema} schema - schema which needs to be normalized
     * @returns {Schema} normalized schema
     */
    normalizeSchemaRelations(schema: Schema): Schema;
    /**
     * Adds the relation type to schema.
     *
     * @param {Schema} schema - schema which needs normalization
     * @return {Schema} normalized schema
     */
    private normalizeOneToOneRelation(schema);
    /**
     * Adds the relation type to schema.
     *
     * @param {Schema} schema - schema which needs normalization
     * @return {Schema} normalized schema
     */
    private normalizeOneToManyRelation(schema);
    /**
     * Adds the relation type to schema.
     *
     * @param {Schema} schema - schema which needs normalization
     * @return {Schema} normalized schema
     */
    private normalizeManyToManyRelation(schema);
}
