"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var logger_1 = require("../../commons/logger");
var chalk = require("chalk");
var inquirer = require("inquirer");
var input = require("../inputs/input");
var ApiFileOperations_1 = require("../../fileOperations/ApiFileOperations");
var config_1 = require("../../configs/config");
var dialect = require("./database/dialect");
exports.questions = [
    {
        name: 'output',
        type: 'input',
        message: 'Api output directory:',
        default: 'api',
    },
    {
        name: 'name',
        type: 'input',
        message: 'Application name (lower case with dashes):',
    },
    {
        name: 'description',
        type: 'input',
        message: 'Application description:',
    },
    {
        name: 'version',
        type: 'input',
        message: 'Version:',
        default: '1.0.0',
    },
    {
        name: 'license',
        type: 'input',
        message: 'Licence:',
        default: 'ISC',
    },
    {
        name: 'author',
        type: 'input',
        message: 'Author:',
    },
];
exports.handler = function (data) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var _this = this;
    var apiFileOperations, schema, connection;
    return tslib_1.__generator(this, function (_a) {
        apiFileOperations = new ApiFileOperations_1.default(data.output);
        logger_1.default.info('generating api');
        return [2 /*return*/, apiFileOperations.createDirectoryStructure()
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('reading input source');
                    return [2 /*return*/, inquirer.prompt(input.questions).then(input.handler)];
                });
            }); })
                .then(function (parsedSchema) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    schema = parsedSchema;
                    logger_1.default.info(JSON.stringify(schema, undefined, config_1.default.DEFAULT_INDENTATION_SPACE_COUNT));
                    return [2 /*return*/, inquirer.prompt(dialect.questions).then(dialect.handler)];
                });
            }); })
                .then(function (connectionData) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    connection = connectionData;
                    logger_1.default.info(JSON.stringify(connection, undefined, 2));
                    logger_1.default.info('requesting consent for installing packages');
                    return [2 /*return*/, inquirer.prompt([{
                                name: 'allow',
                                type: 'confirm',
                                message: chalk.yellow('Allow generaptr to install required packages:'),
                            }])];
                });
            }); })
                .then(function (consent) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    if (!consent.allow) {
                        return [2 /*return*/, Promise.reject('User did not agree that generaptr should install required packages')];
                    }
                    logger_1.default.info('generating package.json');
                    return [2 /*return*/, apiFileOperations.createPackageJson(data, connection.dialect)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing dependencies');
                    return [2 /*return*/, apiFileOperations.installDependencies(connection.dialect)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('initialize odm');
                    return [2 /*return*/, apiFileOperations.initializeORM(connection.dialect)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing config');
                    return [2 /*return*/, apiFileOperations.initializeConfig(connection, schema)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing commons');
                    return [2 /*return*/, apiFileOperations.initializeCommons()];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing models');
                    return [2 /*return*/, apiFileOperations.initializeModels(connection.dialect, schema)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing repositories');
                    return [2 /*return*/, apiFileOperations.initializeRepositories(connection.dialect, schema)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing services');
                    return [2 /*return*/, apiFileOperations.initializeServices(schema)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('installing controllers');
                    return [2 /*return*/, apiFileOperations.initializeControllers(schema)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('finished api generation');
                    return [2 /*return*/, Promise.resolve(true)];
                });
            }); })
                .catch(function (e) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.error(e.message);
                    return [2 /*return*/, Promise.reject(e)];
                });
            }); })];
    });
}); };
