"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var assert = require("assert");
var fs = require("fs");
var path = require("path");
var ApiFileOperations_1 = require("../../src/fileOperations/ApiFileOperations");
var directoryStructure_1 = require("../../src/commons/constants/directoryStructure");
var schemaMocks_1 = require("../testUtils/schemaMocks");
var apiMocks_1 = require("../testUtils/apiMocks");
describe('Suite for testing ApiFileOperation class', function () {
    it('should throw an error if path provided is filePath', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.createDirectoryStructure()
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                done();
                return [2 /*return*/];
            });
        }); })
            .catch(function (exception) {
            assert.equal(exception, 'Invalid directory path');
            done();
        });
    });
    it('should create directory structure', function () {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.createDirectoryStructure()
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                Object.keys(directoryStructure_1.default.API_STRUCTURE).map(function (key) {
                    fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE[key]), function (err, stat) {
                        if (err) {
                            assert.fail(err.message);
                        }
                        assert.equal(stat.isDirectory(), true);
                    });
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (exception) {
            assert.fail(exception.message);
        });
    });
    it('should create config files', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations
            .initializeConfig(apiMocks_1.default.VALID_SEQUELIZE_CONFIG, schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            var _this = this;
            var promises;
            return tslib_1.__generator(this, function (_a) {
                promises = [Promise.resolve(true)];
                // Config folder
                ['config.js', 'index.js', 'database.js', 'express.js', 'router.js'].forEach(function (file) {
                    promises.push(new Promise(function (resolve, reject) {
                        fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONFIG, file), function (err, stats) {
                            if (err) {
                                return reject(err);
                            }
                            return resolve(stats.isFile());
                        });
                    }));
                });
                // Middlewares folder
                promises.push(new Promise(function (resolve, reject) {
                    fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.MIDDLEWARES, 'cors.js'), function (err, stats) {
                        if (err) {
                            return reject(err);
                        }
                        return resolve(stats.isFile());
                    });
                }));
                // Main index
                promises.push(new Promise(function (resolve, reject) {
                    fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.SRC, 'index.js'), function (err, stats) {
                        if (err) {
                            return reject(err);
                        }
                        return resolve(stats.isFile());
                    });
                }));
                Promise.all(promises)
                    .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                    return tslib_1.__generator(this, function (_a) {
                        done();
                        return [2 /*return*/];
                    });
                }); })
                    .catch(function (error) {
                    assert.fail(error.message);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (error) {
            assert.fail(error.message);
            done();
        });
    });
    it('should create util.js and statusCode.js files', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeCommons()
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                // Check util.js file
                fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.COMMONS, "util.js"), function (err, stats) {
                    assert.ifError(err);
                    assert.equal(stats.isFile(), true);
                    // Check statusCode.js file
                    fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONSTANTS, "statusCode.js"), function (error, state) {
                        assert.ifError(error);
                        assert.equal(state.isFile(), true);
                        done();
                    });
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (error) {
            assert.fail(error.message);
            done();
        });
    });
    it('should create services files', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeServices(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.SERVICES, 'userService.js'), function (err, stats) {
                    assert.ifError(err);
                    assert.equal(stats.isFile(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (error) {
            assert.fail(error.message);
            done();
        });
    });
    it('should create controller files', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeControllers(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONTROLLERS, 'userController.js'), function (err, stats) {
                    assert.ifError(err);
                    assert.equal(stats.isFile(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (error) {
            assert.fail(error.message);
            done();
        });
    });
    it('should create a package json', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.createPackageJson(apiMocks_1.default.PACKAGE_JSON_CONFIG, 'MySql')
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), 'package.json'), function (err, stat) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stat.isFile(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); }).catch(function (error) {
            assert.fail(error.message);
            done();
        });
    });
    it('should install required dependencies', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.installDependencies('MySql')
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), 'node_modules'), function (err, stat) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stat.isDirectory(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); }).catch(function (error) {
            assert.fail(error.message);
            done();
        });
    }).timeout(50000);
    it('should not fail install required dependencies for unknown dialects', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.installDependencies('')
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), 'node_modules'), function (err, stat) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stat.isDirectory(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); }).catch(function (error) {
            assert.fail(error.message);
            done();
        });
    }).timeout(50000);
    it('should know how to initialize ORM', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeORM('MySql')
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.MODELS, 'index.js'), function (err, stats) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stats.isFile(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); }).catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should throw an error when trying to initialize ORM for unknown database', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeORM('')
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                assert.fail('should throw an error');
                done();
                return [2 /*return*/];
            });
        }); }).catch(function (err) {
            assert.equal(err, 'Dialect not supported');
            done();
        });
    });
    it('should know how to generate models', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeModels('MySql', schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.MODELS, 'User.js'), function (err, stats) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stats.isFile(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); }).catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should throw an error when trying to initialize models for unknown database', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeModels('', schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                assert.fail('should throw an error');
                done();
                return [2 /*return*/];
            });
        }); }).catch(function (err) {
            assert.equal(err, 'Dialect not supported');
            done();
        });
    });
    it('should know how to generate repositories', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeRepositories('MySql', schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.stat(path.join(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.REPOSITORIES, 'UserRepository.js'), function (err, stats) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stats.isFile(), true);
                    done();
                });
                return [2 /*return*/];
            });
        }); }).catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should throw an error when trying to initialize repositories for unknown database', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        apiFileOperations.initializeRepositories('', schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                assert.fail('should throw an error');
                done();
                return [2 /*return*/];
            });
        }); }).catch(function (err) {
            assert.equal(err, 'Dialect not supported');
            done();
        });
    });
});
