"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var assert = require("assert");
var fs = require("fs");
var path = require("path");
var RamlFileOperations_1 = require("../../src/fileOperations/RamlFileOperations");
var directoryStructure_1 = require("../../src/commons/constants/directoryStructure");
var types_1 = require("../../src/generators/spec/types");
var utils_1 = require("../../src/commons/utils/utils");
var schemaMocks_1 = require("../testUtils/schemaMocks");
var table = {
    name: 'User',
    columns: [
        {
            name: 'id',
            primary: true,
            unique: true,
            allowNull: false,
            dataType: {
                type: 'number',
                size: undefined,
            },
        },
        {
            name: 'firstName',
            primary: false,
            unique: false,
            allowNull: true,
            dataType: {
                type: 'string',
                size: 45,
            },
        },
    ],
};
var schema = schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE;
describe('Suite for testing RamlFileOperation class', function () {
    it('should throw an error if path provided is filePath', function (done) {
        var ramlFileOperations = new RamlFileOperations_1.default('raml.test');
        ramlFileOperations.createDirectoryStructure()
            .then(function () {
            done();
        })
            .catch(function (exception) {
            assert.equal(exception, 'Invalid directory path');
            done();
        });
    });
    it('should create directory structure', function () {
        var ramlFileOperations = new RamlFileOperations_1.default('raml.test');
        ramlFileOperations.createDirectoryStructure()
            .then(function () {
            Object.keys(directoryStructure_1.default.RAML_STRUCTURE).map(function (key) {
                fs.stat(path.join(ramlFileOperations.getFilePath(), directoryStructure_1.default.RAML_STRUCTURE[key]), function (err, stat) {
                    if (err) {
                        assert.fail(err.message);
                    }
                    assert.equal(stat.isDirectory(), true);
                });
            });
        })
            .catch(function (exception) {
            assert.fail(exception.message);
        });
    });
    it('should create raml type file', function (done) {
        var ramlFileOperations = new RamlFileOperations_1.default('raml.test');
        ramlFileOperations.createDirectoryStructure()
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
            return [2 /*return*/, ramlFileOperations.generateSchemaTypeFiles([table])];
        }); }); })
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(path.join(ramlFileOperations.getFilePath(), directoryStructure_1.default.RAML_STRUCTURE.TYPES, table.name + ".raml"), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data, types_1.default.generateTypeContent(table), 'Content should be the same');
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (exception) {
            assert.fail(exception.message);
            done();
        });
    });
    it('should create entity.json files', function (done) {
        var ramlFileOperations = new RamlFileOperations_1.default('raml.test');
        ramlFileOperations.createDirectoryStructure()
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
            return [2 /*return*/, ramlFileOperations.generateSchemaExampleFiles(schema)];
        }); }); })
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(path.join(ramlFileOperations.getFilePath(), directoryStructure_1.default.RAML_STRUCTURE.EXAMPLES, utils_1.default.toTitleCase(schema[0].name) + ".json"), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(Object.keys(JSON.parse(data.toString())).length, schema[0].columns.length, 'Number of attributes should be the same');
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (exception) {
            assert.fail(exception.message);
            done();
        });
    });
    it('should create entity[s].json files', function (done) {
        var ramlFileOperations = new RamlFileOperations_1.default('raml.test');
        ramlFileOperations.createDirectoryStructure()
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
            return [2 /*return*/, ramlFileOperations.generateSchemaExampleFiles(schema)];
        }); }); })
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
            return [2 /*return*/, ramlFileOperations.generateSchemaExamplesFilesFromCache()];
        }); }); })
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(path.join(ramlFileOperations.getFilePath(), directoryStructure_1.default.RAML_STRUCTURE.EXAMPLES, utils_1.default.pluralize(utils_1.default.toTitleCase(schema[0].name)) + ".json"), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Countent should not be empty');
                    assert.equal(JSON.parse(data.toString()).length, 2, 'Number of entities should be 2');
                    for (var _i = 0, _a = JSON.parse(data.toString()); _i < _a.length; _i++) {
                        var entity = _a[_i];
                        assert.equal(Object.keys(entity).length, 4, 'Number of attributes for every entity should be 4');
                    }
                });
                done();
                return [2 /*return*/];
            });
        }); })
            .catch(function (exception) {
            assert.fail(exception.message);
            done();
        });
    });
    it('should create api.raml files', function (done) {
        var ramlFileOperations = new RamlFileOperations_1.default('raml.test');
        ramlFileOperations.generateSchemaApiFiles([{ name: 'users', columns: [] }], { name: 'Test Test', version: 'v1', url: '/', output: ramlFileOperations.getFilePath() })
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(path.join(ramlFileOperations.getFilePath(), 'api.raml'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (exception) {
            assert.fail(exception.message);
            done();
        });
    });
});
