"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var assert = require("assert");
var fs = require("fs");
var fileUtil_1 = require("../../../src/commons/utils/fileUtil");
var directoryStructure_1 = require("../../../src/commons/constants/directoryStructure");
var ApiFileOperations_1 = require("../../../src/fileOperations/ApiFileOperations");
var configurationsFileOperations_1 = require("../../../src/fileOperations/api/configurationsFileOperations");
var apiMocks_1 = require("../../testUtils/apiMocks");
var schemaMocks_1 = require("../../testUtils/schemaMocks");
describe('Suite for testing the ConfigurationsFileOperations class', function () {
    it('should create config.js file', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeConfig(apiFileOperations.getFilePath())
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONFIG, 'config.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_CONFIG_VALUE);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should create index.js file from config folder', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeGetEnvBasedConfig(apiFileOperations.getFilePath())
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONFIG, 'index.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_CONFIG_GET_ENV_BASED_CONFIG);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should create database.js file from config folder', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeDbConfig(apiMocks_1.default.VALID_SEQUELIZE_CONFIG, apiFileOperations.getFilePath())
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONFIG, 'database.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_SEQUELIZE_DATABASE_CONFIG);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should create cors.js file from config folder', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeCorsConfig(apiFileOperations.getFilePath())
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.MIDDLEWARES, 'cors.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_CORS_CONFIG);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should create express.js file from config folder', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeExpressConfig(apiFileOperations.getFilePath())
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONFIG, 'express.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_EXPRESS_CONFIG);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should create router.js file from config folder', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeRouterConfig(apiFileOperations.getFilePath(), schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE)
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.CONFIG, 'router.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_ROUTER_CONFIG);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
    it('should create index.js main app file', function (done) {
        var apiFileOperations = new ApiFileOperations_1.default('api.test');
        configurationsFileOperations_1.default.initializeIndex(apiFileOperations.getFilePath())
            .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                fs.readFile(fileUtil_1.default.joinPaths(apiFileOperations.getFilePath(), directoryStructure_1.default.API_STRUCTURE.SRC, 'index.js'), function (err, data) {
                    assert.ifError(err);
                    assert(data, 'Content should not be empty');
                    assert.equal(data.toString(), apiMocks_1.default.VALID_INDEX_FILE);
                    done();
                });
                return [2 /*return*/];
            });
        }); })
            .catch(function (err) {
            assert.fail(err.message);
            done();
        });
    });
});
