"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var sequelize_1 = require("../../../../src/generators/api/models/sequelize");
var apiMocks_1 = require("../../../testUtils/apiMocks");
var schemaMocks_1 = require("../../../testUtils/schemaMocks");
var sequelizeModelGenerator = new sequelize_1.default();
describe('Suite for testing the SequelizeModelGenerator class', function () {
    it('should generate a valid model registry', function () {
        assert.equal(sequelizeModelGenerator.getModelsRegistry(), apiMocks_1.default.VALID_SEQUELIZE_MODEL_REGISTRY);
    });
    it('should generate a valid configuration file', function () {
        assert.equal(sequelizeModelGenerator.getConfig(apiMocks_1.default.VALID_SEQUELIZE_CONFIG), apiMocks_1.default.VALID_SEQUELIZE_DATABASE_CONFIG);
    });
    it('should know how to generate valid models for a simple schema', function () {
        var models = sequelizeModelGenerator.getModels(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE);
        assert.equal(models[0].name, 'User.js');
    });
    it('should know how to generate valid models for a schema with a one to one relation', function () {
        var models = sequelizeModelGenerator.getModels(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE);
        assert.equal(models[0].name, 'Account.js');
        assert.equal(models[1].name, 'User.js');
    });
    it('should know how to generate valid models for a schema with a one to many relation', function () {
        var models = sequelizeModelGenerator.getModels(schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE);
        assert.equal(models[0].name, 'Account.js');
        assert.equal(models[1].name, 'Application.js');
        models = sequelizeModelGenerator.getModels(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_MANY);
        assert.equal(models[0].name, 'Account.js');
        assert.equal(models[1].name, 'Application.js');
    });
    it('should know how to generate valid models for a schema with a many to many relation', function () {
        var models = sequelizeModelGenerator.getModels(schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_MANY);
        assert.equal(models[0].name, 'Group.js');
        assert.equal(models[1].name, 'User.js');
    });
    it('should know how to generate valid models for a schema with enum field', function () {
        var models = sequelizeModelGenerator.getModels(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE_WITH_ENUM);
        assert.equal(models[0].name, 'User.js');
    });
    it('should not fail for unknown column type or relation', function () {
        var invalidSchema = [
            {
                name: 'users',
                columns: [
                    {
                        name: 'type',
                        primary: false,
                        unique: false,
                        allowNull: false,
                        dataType: {
                            type: 'wrong-type',
                        },
                    },
                    {
                        name: 'relation',
                        primary: false,
                        unique: false,
                        allowNull: false,
                        dataType: {
                            type: 'Account',
                            relationType: undefined,
                        },
                    },
                ],
            },
        ];
        var models = sequelizeModelGenerator.getModels(invalidSchema);
        assert.equal(models[0].name, 'User.js');
    });
});
