"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var packageJson_1 = require("../../../src/generators/api/packageJson");
var apiMocks_1 = require("../../testUtils/apiMocks");
describe('Suite for testing the PackageJsonGenerator class', function () {
    it('should know how to generate a valid package json', function () {
        var generated = packageJson_1.default.getPackageJson(apiMocks_1.default.PACKAGE_JSON_CONFIG, 'MySql');
        assert.equal(generated.name, apiMocks_1.default.VALID_PACKAGE_JSON.name);
        assert.equal(generated.version, apiMocks_1.default.VALID_PACKAGE_JSON.version);
        assert.equal(generated.description, apiMocks_1.default.VALID_PACKAGE_JSON.description);
        assert.equal(generated.main, apiMocks_1.default.VALID_PACKAGE_JSON.main);
        assert.deepEqual(generated.scripts, apiMocks_1.default.VALID_PACKAGE_JSON.scripts);
        assert.equal(generated.author, apiMocks_1.default.VALID_PACKAGE_JSON.author);
        assert.equal(generated.license, apiMocks_1.default.VALID_PACKAGE_JSON.license);
        assert.deepEqual(generated.dependencies, apiMocks_1.default.VALID_PACKAGE_JSON.dependencies);
    });
    it('should know how to return a valid package json as string', function () {
        assert.equal(packageJson_1.default.getPackageJsonAsString(apiMocks_1.default.PACKAGE_JSON_CONFIG, 'MySql'), JSON.stringify(apiMocks_1.default.VALID_PACKAGE_JSON, undefined, 2));
    });
    it('should not generate scripts for an unknown database dialect', function () {
        var validScripts = {
            'test': 'echo \'Error: no test specified\' && exit 1',
            'start': 'node src/index.js',
            'start:dev': './node_modules/.bin/nodemon src/index.js',
        };
        var generated = packageJson_1.default.getPackageJson(apiMocks_1.default.PACKAGE_JSON_CONFIG, 'unknown driver');
        assert.deepEqual(generated.scripts, validScripts);
    });
});
