"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var spec_1 = require("../../../src/generators/spec/spec");
var VALID_HEADER = "#%RAML 1.0\ntitle: Test Title\nversion: v1\nbaseUri: /{version}\nprotocols: [HTTP, HTTPS]\n";
var VALID_DATA_TYPES = "types:\n  User: !include types/User.raml\n";
var VALID_GET_ALL = "  get:\n    description: Get a list of all users\n    responses:\n      200:\n        body:\n          application/json:\n            type: User[]\n            example: !include examples/Users.json\n";
var VALID_CREATE = "  post:\n    description: Create a user\n    body:\n      application/json:\n        type: User\n    responses:\n      201:\n        body:\n          application/json:\n            type: User\n            example: !include examples/User.json\n";
var VALID_GET_ONE = "    get:\n      description: Get an instance of user based on it's id.\n      responses:\n        200:\n          body:\n            application/json:\n              type: User\n              example: !include examples/User.json\n";
var VALID_UPDATE = "    put:\n      description: Update an instance of user.\n      body:\n        application/json:\n          type: User\n      responses:\n        200:\n          body:\n            application/json:\n              type: User\n              example: !include examples/User.json\n";
var VALID_DELETE = "    delete:\n      description: Delete an instance of user based on it's id.\n      responses:\n        204:\n";
describe('Suite for testing RamlSpecGeneratorr', function () {
    it('should generate a valid get all spec', function () {
        assert.equal(spec_1.default.addGetAllSpec('  ', { name: 'users', columns: [] }), VALID_GET_ALL);
    });
    it('should generate a valid create spec', function () {
        assert.equal(spec_1.default.addCreateSpec('  ', { name: 'users', columns: [] }), VALID_CREATE);
    });
    it('should generate a valid get one spec', function () {
        assert.equal(spec_1.default.addGetOneSpec('  ', { name: 'users', columns: [] }), VALID_GET_ONE);
    });
    it('should generate a valid update spec', function () {
        assert.equal(spec_1.default.addUpdateSpec('  ', { name: 'users', columns: [] }), VALID_UPDATE);
    });
    it('should generate a valid delete spec', function () {
        assert.equal(spec_1.default.addDeleteSpec('  ', { name: 'users', columns: [] }), VALID_DELETE);
    });
    it('should add the data types', function () {
        assert.equal(spec_1.default.addDataTypes([{ name: 'users', columns: [] }]), VALID_DATA_TYPES);
    });
    it('should add the generic info', function () {
        assert.equal(spec_1.default.addHeaderContent({ name: 'Test Title', version: 'v1', url: '/', output: '' }), VALID_HEADER);
    });
});
