"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var types_1 = require("../../../src/generators/spec/types");
var table = {
    name: 'users',
    columns: [
        {
            name: 'id',
            allowNull: false,
            unique: true,
            primary: true,
            dataType: {
                type: 'number',
                size: undefined,
            },
        },
        {
            name: 'firstName',
            allowNull: true,
            unique: false,
            primary: false,
            dataType: {
                type: 'string',
                size: 45,
            },
        },
        {
            name: 'roles',
            allowNull: true,
            unique: false,
            primary: false,
            dataType: {
                type: 'Role',
                isArray: true,
            },
        },
    ],
};
var enumTable = {
    name: 'users',
    columns: [
        {
            name: 'isActive',
            primary: false,
            allowNull: false,
            unique: false,
            dataType: {
                type: 'enum',
                isArray: false,
                values: ['No', 'Yes'],
            },
        },
    ],
};
describe('Suite for testing RamlTypesGenerator', function () {
    it('should create raml type content', function () {
        var expectedResponse = "#%RAML 1.0 DataType\ntype: object\nproperties:\n  id:\n    required: true\n    type: number\n  firstName:\n    required: false\n    type: string\n  roles:\n    required: false\n    type: Role[]\n";
        var typeContent = types_1.default.generateTypeContent(table);
        assert.equal(typeContent, expectedResponse);
    });
    it('should create raml type content for enum', function () {
        var expectedResponse = "#%RAML 1.0 DataType\ntype: object\nproperties:\n  isActive:\n    required: true\n    type: No | Yes\n";
        var typeContent = types_1.default.generateTypeContent(enumTable);
        assert.equal(typeContent, expectedResponse);
    });
});
