"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var MysqlHandler_1 = require("../../../src/handlers/MysqlHandler");
var config_1 = require("../../../src/configs/config");
var validConnectionData = config_1.default.CONNECTION_INFO.MYSQL[config_1.default.ENV];
describe('Suite for testing MySqlHandler class', function () {
    var handler;
    beforeEach(function () {
        handler = new MysqlHandler_1.default(validConnectionData);
        handler.connect();
    });
    afterEach(function () {
        if (handler) {
            handler.close();
        }
        handler = undefined;
    });
    it('should return an array with the table names', function (done) {
        try {
            if (handler) {
                handler.getTables().then(function (tableNames) {
                    assert.equal(tableNames.length, 5);
                    done();
                }).catch(function (err) {
                    console.log(err);
                    assert.fail(err.message);
                    done();
                });
            }
        }
        catch (e) {
            assert.fail(e);
            done();
        }
    });
    it('should return a valid table schema', function (done) {
        try {
            if (handler) {
                handler.getTableSchema('users').then(function (table) {
                    assert.equal(table.name, 'users');
                    assert.equal(Object.keys(table.columns).length, 4);
                    done();
                }).catch(function (err) {
                    console.log(err);
                    assert.fail(err.message);
                    done();
                });
            }
        }
        catch (e) {
            assert.fail(e.message);
            done();
        }
    });
    it('should detect a table relation', function (done) {
        try {
            if (handler) {
                handler.getRelationsForTable('accounts').then(function (relations) {
                    var relation = relations.pop();
                    if (relation) {
                        assert.equal(relation.table, 'users');
                        assert.equal(relation.column, 'id');
                        assert.equal(relation.name, 'user_id');
                    }
                    done();
                }).catch(function (err) {
                    console.log(err);
                    assert.fail(err.message);
                    done();
                });
            }
        }
        catch (e) {
            assert.fail(e.message);
            done();
        }
    });
    it('should return a valid database schema', function (done) {
        try {
            if (handler) {
                handler.readSchema().then(function (schema) {
                    assert.equal(schema.length, 4);
                    var users = schema.filter(function (table) { return table.name === 'users'; })[0];
                    var accounts = schema.filter(function (table) { return table.name === 'accounts'; })[0];
                    assert.equal(users.name, 'users');
                    assert.equal(Object.keys(users.columns).length, 6);
                    assert.equal(accounts.name, 'accounts');
                    assert.equal(Object.keys(accounts.columns).length, 4);
                    done();
                }).catch(function (err) {
                    console.log(err);
                    assert.fail(err.message);
                    done();
                });
            }
        }
        catch (e) {
            assert.fail(e.message);
            done();
        }
    });
});
