"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var MysqlSchemaPreprocessor_1 = require("../../src/preprocesors/MysqlSchemaPreprocessor");
var assert = require("assert");
var schemaMocks_1 = require("../testUtils/schemaMocks");
var preProcessor = new MysqlSchemaPreprocessor_1.default();
describe('Suite for testing MySqlPreProcessor class', function () {
    it('should convert a valid column schema to standard schema', function () {
        var colSchema = {
            COLUMN_NAME: 'test',
            COLUMN_TYPE: '',
            COLUMN_KEY: 'PRI',
            IS_NULLABLE: 'NO',
            DATA_TYPE: 'varchar',
            CHARACTER_MAXIMUM_LENGTH: '255',
        };
        var processed = preProcessor.convertToStandardSchema(colSchema);
        assert.equal(processed.name, 'test');
        assert.equal(processed.primary, true);
        assert.equal(processed.allowNull, false);
        assert.equal(processed.foreignKey, false);
        assert.equal(processed.unique, true);
        assert.equal(processed.dataType.type, 'string');
        assert.equal(processed.dataType.size, 255);
    });
    it('should process values for enum data type', function () {
        var processedSchema = preProcessor.convertToStandardSchema(schemaMocks_1.default.RAW_ENUM_DATA);
        assert.ok(processedSchema.dataType);
        assert.equal(processedSchema.dataType.type, "enum");
        assert.ok(processedSchema.dataType.values);
        assert(processedSchema.dataType.values);
        assert.deepEqual(processedSchema.dataType.values, ['No', 'Yes']);
    });
    it('should clean up table schema', function () {
        var schema = schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TABLE;
        var valid = schema[0];
        var processed = preProcessor.normalizeSchemaRelations(schemaMocks_1.default.SCHEMA_ONE_TABLE).pop();
        if (processed) {
            assert.equal(processed.name, valid.name);
            assert.equal(processed.columns.length, valid.columns.length);
        }
        else {
            assert.fail('table schema not cleaned up.');
        }
    });
    it('should normalize one to one relations', function () {
        var schema = schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE;
        var validAccounts = schema[0];
        var validUsers = schema[1];
        var processed = preProcessor.normalizeSchemaRelations(schemaMocks_1.default.SCHEMA_ONE_TO_ONE);
        var processedAccounts = processed[0];
        var processedUsers = processed[1];
        assert.equal(processedAccounts.name, validAccounts.name);
        assert.equal(processedAccounts.columns.length, validAccounts.columns.length);
        assert.equal(processedUsers.name, validUsers.name);
        assert.equal(processedUsers.columns.length, validUsers.columns.length);
    });
    it('should normalize many to one relations', function () {
        var validAccounts = schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE[0];
        var validApplications = schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE[1];
        var processed = preProcessor.normalizeSchemaRelations(schemaMocks_1.default.SCHEMA_MANY_TO_ONE);
        var processedAccounts = processed[0];
        var processedApplications = processed[1];
        assert.equal(processedAccounts.name, validAccounts.name);
        assert.equal(processedAccounts.columns.length, validAccounts.columns.length);
        assert.equal(processedApplications.name, validApplications.name);
        assert.equal(processedApplications.columns.length, validApplications.columns.length);
    });
    it('should normalize many to many relations', function () {
        var validGroups = schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_MANY[0];
        var validUsers = schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_MANY[1];
        var processed = preProcessor.normalizeSchemaRelations(schemaMocks_1.default.SCHEMA_MANY_TO_MANY);
        var processedGroups = processed[0];
        var processedUsers = processed[1];
        assert.equal(processedGroups.name, validGroups.name);
        assert.equal(processedGroups.columns.length, validGroups.columns.length);
        assert.equal(processedUsers.name, validUsers.name);
        assert.equal(processedUsers.columns.length, validUsers.columns.length);
    });
});
