"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var schemaUtil_1 = require("../../src/commons/utils/schemaUtil");
var schemaMocks_1 = require("../testUtils/schemaMocks");
describe('Suite for testing SchemaUtil class', function () {
    it('should get normalized table by type', function () {
        var table = schemaUtil_1.default.getNormalizedTableByType([{ name: 'users', columns: [] }], 'User');
        if (!table) {
            assert.fail('table not found in schema.');
        }
        else {
            assert.equal(table.name, 'users');
        }
    });
    it('should return false if nothing found', function () {
        var table = schemaUtil_1.default.getNormalizedTableByType([{ name: 'users', columns: [] }], 'Account');
        assert.equal(table, undefined);
    });
    it('should know how to convert enum values', function () {
        assert.equal(Number(schemaUtil_1.default.convertValues({
            name: '',
            primary: false,
            unique: false,
            allowNull: true,
            dataType: {
                type: 'enum',
                rawValues: '',
            },
        }).dataType.values), 0);
    });
    it('should convert raml values', function () {
        var values = ['Yes', 'No'];
        var ramlValues = schemaUtil_1.default.valuesToRamlDataType(values);
        assert(ramlValues);
        assert.equal(ramlValues.length, 8);
        assert.equal(ramlValues, 'Yes | No');
        assert.equal(schemaUtil_1.default.valuesToRamlDataType([]), '');
    });
    it('should detect if relation is circular', function () {
        assert.equal(schemaUtil_1.default.isCircularRelation(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0].columns[2], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE), true);
        assert.equal(schemaUtil_1.default.isCircularRelation(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0].columns[1], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE), false);
    });
    it('should detect if refferenced column is required', function () {
        assert.equal(schemaUtil_1.default.circularRelationIsRequired(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[1], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[1].columns[4], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE), true);
        assert.equal(schemaUtil_1.default.circularRelationIsRequired(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0].columns[1], schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE), false);
    });
    it('should detect if refferenced column is array', function () {
        assert.equal(schemaUtil_1.default.circularRelationIsArray(schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE[1], schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE[1].columns[2], schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE), true);
        assert.equal(schemaUtil_1.default.circularRelationIsArray(schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE[0], schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE[0].columns[1], schemaMocks_1.default.PROCESSED_SCHEMA_MANY_TO_ONE), false);
    });
    it('should get related Tables for a given Table', function () {
        var related = schemaUtil_1.default.getRelatedTablesForTable(schemaMocks_1.default.PROCESSED_SCHEMA_ONE_TO_ONE[0]);
        assert.equal(related.length, 1);
        assert.equal(related[0], 'User');
    });
});
