"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var typeUtil_1 = require("../../src/commons/utils/typeUtil");
var assert = require("assert");
describe('Suite for testing TypeConverter class', function () {
    it('should convert to string types', function () {
        assert.equal(typeUtil_1.default.convertSqlType('varchar'), 'string');
    });
    it('should convert to number type', function () {
        assert.equal(typeUtil_1.default.convertSqlType('decimal'), 'number');
    });
    it('should convert to date-only type', function () {
        assert.equal(typeUtil_1.default.convertSqlType('date'), 'date-only');
    });
    it('should convert to datetime type', function () {
        assert.equal(typeUtil_1.default.convertSqlType('datetime'), 'datetime');
    });
    it('should convert to time-only type', function () {
        assert.equal(typeUtil_1.default.convertSqlType('time'), 'time-only');
    });
    it('should throw an error if type not found', function () {
        try {
            typeUtil_1.default.convertSqlType('type-that-does-not-exist');
        }
        catch (e) {
            assert.equal(e.message, 'Type not found');
        }
    });
    it('should throw an error for no-sql types as those are not implemented yet', function () {
        try {
            typeUtil_1.default.convertNoSqlType('int');
        }
        catch (e) {
            assert.equal(e.message, 'int not yet implemented.');
        }
    });
    it('should should convert raml enum types', function () {
        var converted = typeUtil_1.default.convertRamlTypes({ type: 'Yes | No', items: '' });
        assert.equal(converted.type, 'enum');
        if (!converted.values) {
            assert.fail('conversion failed');
        }
        else {
            assert.equal(converted.values.length, 2);
        }
    });
    it('should should convert raml array types', function () {
        var converted = typeUtil_1.default.convertRamlTypes({ type: 'array', items: 'User' });
        assert.equal(converted.type, 'User');
        assert.equal(converted.isArray, true);
    });
    it('should should convert raml ordinary types', function () {
        var converted = typeUtil_1.default.convertRamlTypes({ type: 'number', items: '' });
        assert.equal(converted.type, 'number');
        assert.equal(converted.isArray, false);
    });
    it('should convert enum data type to string', function () {
        var asString = typeUtil_1.default.getEnumValuesAsString({ type: 'enum', values: ['Yes', 'No'] });
        assert.equal(asString, "'Yes', 'No'");
        assert.equal('', typeUtil_1.default.getEnumValuesAsString({ type: 'string' }));
    });
    it('should detect if given type is part of raml default types', function () {
        assert.equal(typeUtil_1.default.isDefaultType('number'), true);
        assert.equal(typeUtil_1.default.isDefaultType('User'), false);
    });
});
