export declare type MapOfStrings = {
    [key: string]: string;
};
export declare type RamlColumnSchema = {
    name: string;
    displayName: string;
    typePropertyKind: string;
    type: string[];
    required: boolean;
    items: string;
};
export declare type RamlType = {
    name(): string;
    toJSON(value: Object): {
        [key: string]: {
            properties: RamlColumnSchema[];
        };
    };
};
export declare type MySqlColumnSchema = {
    COLUMN_NAME: string;
    COLUMN_KEY: string;
    COLUMN_TYPE: string;
    IS_NULLABLE: string;
    DATA_TYPE: string;
    CHARACTER_MAXIMUM_LENGTH?: string;
};
export declare type RawTableReference = {
    COLUMN_NAME: string;
    REFERENCED_TABLE_NAME: string;
    REFERENCED_COLUMN_NAME: string;
};
export declare type TableReference = {
    name: string;
    table: string;
    column: string;
};
export declare type DataType = {
    type: string;
    size?: number;
    rawValues?: string;
    values?: string[];
    isArray?: boolean;
    relationType?: '1-1' | '1-n' | 'n-n';
    isRelationHolder?: boolean;
    references?: TableReference;
};
export declare type Column = {
    name: string;
    primary: boolean;
    unique: boolean;
    foreignKey?: boolean;
    allowNull: boolean;
    dataType: DataType;
};
export declare type Table = {
    name: string;
    columns: Column[];
};
export declare type Schema = Table[];
export declare type StringMapOfStrings = {
    [key: string]: string[];
};
export declare type Everything = string | number | Object | string[] | number[] | Object[] | {};
export declare type Cache = {
    [key: string]: {
        [key: string]: Everything;
    };
};
export declare type Example = {
    type: string;
    data: {
        [key: string]: Everything;
    };
};
export declare type RAMLApplicationInfo = {
    name: string;
    version: string;
    url: string;
    output: string;
};
export declare type ConnectionData = {
    user: string;
    password: string;
    host: string;
    port: string;
    database: string;
    dialect: string;
};
export declare type SequleizeConfig = {
    development: {
        uri: string;
        username: string;
        password: string;
        database: string;
        host: string;
        dialect: string;
        port: string;
    };
    production: {
        uri: string;
        username: string;
        password: string;
        database: string;
        host: string;
        dialect: string;
        port: string;
    };
};
export declare type PackageJson = {
    name: string;
    version: string;
    description: string;
    main: string;
    scripts: {
        [key: string]: string;
    };
    author: string;
    license: string;
    dependencies: MapOfStrings;
};
export declare type PackageJsonInfo = {
    name: string;
    version: string;
    description: string;
    author: string;
    license: string;
    output: string;
};
