import { Everything } from '../types';
/**
 * Class which holds helper tools when working with cache.
 *
 * @export
 * @class CacheUtil
 */
export declare class CacheUtil {
    /**
     * Cache registry.
     *
     * @private
     * @type {Cache}
     * @memberof CacheUtil
     */
    private cache;
    constructor();
    /**
     * Add new key/value pair in cache
     * @param {string} primeKey - primary identicator
     * @param {string} key - unique string value
     * @param {Everything} value - value object to be added in cache
     */
    add(primeKey: string, key: string, value: Everything): void;
    /**
     * Get data by key from cache
     * @param {string} primeKey - primary identicator
     * @param {string} key - key saved in cache
     * @return {*} value out of cache
     */
    get(primeKey: string, key: string): Everything;
    /**
     * Get cache information by prime key
     * @param {string} primeKey key where to get the cache from
     * @return {*} get cache at prime key
     */
    getByPrimeKey(primeKey: string): {
        [key: string]: Everything;
    };
}
declare const _default: CacheUtil;
export default _default;
