/**
 * Class which holds helper tools when working with files.
 *
 * @export
 * @class FileUtil
 */
export declare class FileUtil {
    /**
     * Normalize folder path
     * @param {string} filePath path to be normalized
     * @returns {*} normalized path
     */
    normalizePath(filePath: string): string;
    /**
     * Check if a filePath represents the path for a directory or a file
     * @param {string} filePath - relative or absolute file path
     * @returns {boolean} check if path is dir
     */
    isDirectory(filePath: string): boolean;
    /**
     * Create directory if not exist
     * @param {string} filePath path where the directory should be created.
     * @returns {Promise} directory created
     */
    createDirectory(filePath: string): Promise<boolean>;
    /**
     * Join list of paths
     * @param {Array<string>} paths array of paths that need to be merged
     * @returns {string} merged path
     */
    joinPaths(...paths: string[]): string;
    /**
     * Writes content into file.
     *
     * @param {string} filePath - destination file
     * @param {string} content - content to be written
     * @returns {Promise} file written
     */
    writeFile(filePath: string, content: string): Promise<boolean>;
}
declare const _default: FileUtil;
export default _default;
