/**
 * Export utils class.
 *
 * @export
 * @class Utils
 */
export declare class Utils {
    /**
     * Convert data type name to 'Object' naming
     * @param {string} word - eg: users
     * @returns {string} eg: User
     */
    toTitleCase(word: string): string;
    /**
     * Convert word to it's table name
     * @param {string} word = eg: User
     * @return {string} eg: users
     */
    toTableName(word: string): string;
    /**
     * Pluralizes a word.
     * @param {string} word - eg: user
     * @return {string} eg: users
     */
    pluralize(word: string): string;
    /**
     * Convert plural word into singular
     * @param {string} word - word to be singularized
     * @returns {string} - singularized word
     */
    singular(word: string): string;
    /**
     * Pluralise a word that contains [] at the end
     * @param {string} word - string object
     * @return {string} - Example: input: User[]; output: Users
     */
    pluraliseWordArray(word: string): string;
    /**
     * Convert js plain object into JSON string
     * @param {{}} object - object to be converted
     * @return {string} stringy version of js object
     */
    convertToJSON(object: Object): string;
    /**
     * IndexOf implementation with ignore case
     * @param {string[]} haystack - array of strings
     * @param {string} needle - query string
     * @return {number} key of the query inside the array
     */
    indexOfIgnoreCase(haystack: string[], needle: string): number;
    /**
     * Returns an array of a certain length with same object
     * @param {{}} object - js plain object
     * @param {int} length - length of returned array
     * @return {Array.<{}>} filled array
     */
    fillArray(object: Object, length: number): Object[];
    /**
     * Formats the line for spec.
     *
     * @param {string} initialIndentation - holds the initial indentation
     * @param {number} tabs - holds how many tabs should prepend to the line
     * @param {string} message - holds the actual content of the line
     * @return {string} - returns the formatted line
     */
    formatLine(initialIndentation: string, tabs: number, message: string): string;
}
declare const _default: Utils;
export default _default;
