import { PackageJsonInfo, ConnectionData, Schema } from '../commons/types';
/**
 * Class which implements the logic for implementing api generation file related actions.
 *
 * @export
 * @class ApiFileOperations
 */
export default class ApiFileOperations {
    /**
     * Path to the folder where the api will be generated.
     *
     * @private
     * @type {string}
     * @memberOf ApiFileOperations
     */
    private filePath;
    constructor(filePath: string);
    /**
     * Create directory structure for the application
     * @returns {Promise<boolean[]>} created directory structure.
     */
    createDirectoryStructure(): Promise<boolean[]>;
    /**
     * Creates package json
     *
     * @param {PackageJsonInfo} options - package json options
     * @param {string} dialect - database dialect
     * @returns {Promise<boolean>} created package json
     */
    createPackageJson(options: PackageJsonInfo, dialect: string): Promise<boolean>;
    /**
     * Install dependencies for api stub
     *
     * @param {string} dialect database type
     * @return {Promise<boolean>} installed dependencies
     */
    installDependencies(dialect: string): Promise<boolean>;
    /**
     * Initialize ODM
     *
     * @param {string} dialect database dialect
     * @returns {Promise<boolean>} initialized orm
     */
    initializeORM(dialect: string): Promise<boolean>;
    /**
     * Generate config
     * @param {ConnectionData} connection - connection info
     * @param {Schema} schema - database schema tables
     * @returns {Promise<boolean[]>} - true if generated config
     * @memberOf ApiFileOperations
     */
    initializeConfig(connection: ConnectionData, schema: Schema): Promise<boolean[]>;
    /**
     * Initialize commons
     * @return {Promise<boolean[]>}
     */
    initializeCommons(): Promise<boolean[]>;
    /**
     * Initialize ODM
     *
     * @param {string} dialect database dialect
     * @param {Schema} schema source schema for api generation
     * @returns {Promise<boolean[]>} initialized odm
     */
    initializeModels(dialect: string, schema: Schema): Promise<boolean[]>;
    /**
     * Initialize Repositories
     *
     * @param {string} dialect database dialect
     * @param {Schema} schema source schema for api generation
     * @returns {Promise<boolean[]>} initialized repositories
     */
    initializeRepositories(dialect: string, schema: Schema): Promise<boolean[]>;
    /**
     * Initialize Services
     * @param schema
     * @return {Promise<Promise<boolean[]>>}
     */
    initializeServices(schema: Schema): Promise<boolean[]>;
    /**
     * Initialize Controllers
     * @param schema
     * @return {Promise<boolean[]>}
     */
    initializeControllers(schema: Schema): Promise<boolean[]>;
    /**
     * Get required dependencies based on database type
     *
     * @param {string} databaseType database type
     * @return {string} required dependencies for the database type
     */
    private getDependenciesForDb(dialect);
    /**
     * Returns file path.
     *
     * @returns {string} file path
     */
    getFilePath(): string;
}
