import { Schema, RAMLApplicationInfo } from '../commons/types';
/**
 * Class which implements the logic for implementing raml generation file related actions.
 *
 * @export
 * @class RamlFileOperations
 */
export default class RamlFileOperations {
    /**
     * Path to the folder where the raml will be generated.
     *
     * @private
     * @type {string}
     * @memberof ApiFileOperations
     */
    private filePath;
    constructor(filePath: string);
    /**
     * Create directory structure for the application
     * @returns {Promise<boolean[]>} created directory structure.
     */
    createDirectoryStructure(): Promise<boolean[]>;
    /**
     * Create .raml type file for every table inside schema
     * @param {Schema} schema - schema tables(list of tables)
     * @returns {Promise.<boolean[]>} generated type files.
     */
    generateSchemaTypeFiles(schema: Schema): Promise<boolean[]>;
    /**
     * Generate api.raml spec for the whole api.
     *
     * @param {Schema} schema - database schema
     * @param {RAMLApplicationInfo} options - application info
     * @returns {Promise<boolean>} - true if spec generated
     */
    generateSchemaApiFiles(schema: Schema, options: RAMLApplicationInfo): Promise<boolean>;
    /**
     * Generate .json entity for every table from schema.
     * File will be saved on path: ./raml/types/entityName.json
     * @param {Schema} schema - schema containing tables.
     * @return {Promise.<boolean[]>} generated examle files.
     */
    generateSchemaExampleFiles(schema: Schema): Promise<boolean[]>;
    /**
     * Generate .json Array entity for every array of objects saved in cache
     * @return {Promise.<boolean[]>} generated example files.
     */
    generateSchemaExamplesFilesFromCache(): Promise<boolean[]>;
    /**
     * Returns file path.
     *
     * @returns {string} file path
     */
    getFilePath(): string;
}
