import { ConnectionData, Schema } from '../../commons/types';
/**
 * Class which implements logic for creating configuration files
 *
 * @export
 * @class ConfigurationFileOperations
 */
export declare class ConfigurationFileOperations {
    /**
     * Generate general configuration
     * @param {string} filePath - file path where api will be generated
     * @return {Promise<boolean>}
     */
    initializeConfig(filePath: string): Promise<boolean>;
    /**
     * Generate get env based config util class
     * @param {string} filePath - file path where api will be generated
     * @return {Promise<boolean>}
     */
    initializeGetEnvBasedConfig(filePath: string): Promise<boolean>;
    /**
     * Generate database configuration
     * @param {Connection data} connection - connection info
     * @param {string} filePath - file path where api will be generated
     * @return {Promise<boolean>}
     */
    initializeDbConfig(connection: ConnectionData, filePath: string): Promise<boolean>;
    /**
     * Initialize cors configuration
     * @param filePath - file path where api will be generated
     * @return {Promise<boolean>} - true if cors file was successfully created
     */
    initializeCorsConfig(filePath: string): Promise<boolean>;
    /**
     * Initialize express configuration
     * @param filePath - file path where api will be generated
     * @return {Promise<boolean>} - true if express file was successfully created
     */
    initializeExpressConfig(filePath: string): Promise<boolean>;
    /**
     * Initialize express configuration
     * @param filePath - file path where api will be generated
     * @param schema - database schema table
     * @return {Promise<boolean>}
     */
    initializeRouterConfig(filePath: string, schema: Schema): Promise<boolean>;
    /**
     * Initialize main index.js file
     * @param filePath - file path where api will be generated
     * @return {Promise<boolean>} - true if index file was created
     */
    initializeIndex(filePath: string): Promise<boolean>;
}
declare const _default: ConfigurationFileOperations;
export default _default;
