import { ConnectionData, Schema } from '../../../commons/types';
/**
 * Class which implements the logic for generating valid sequelize files.
 *
 * @export
 * @class SequelizeModelGenerator
 */
export default class SequelizeModelGenerator {
    /**
     * Returns the string version of the code which will manage the sequelzie models.
     *
     * @returns {string} - sequelize models registry
     * @memberof SequelizeModelGenerator
     */
    getModelsRegistry(): string;
    /**
     * Returns the sequelize config
     *
     * @param {ConnectionData} connection - connection data
     * @returns {string} - connection string
     * @memberof SequelizeModelGenerator
     */
    getConfig(connection: ConnectionData): string;
    /**
     * Generate models for a given schema.
     *
     * @param {Schema} schema - api schema
     * @return {{name: string, content: string}[]}
     */
    getModels(schema: Schema): {
        name: string;
        content: string;
    }[];
    /**
     * Generate contents for each model based on the table schema.
     *
     * @param {Table} table - source
     * @return {string} content of sequelize model as string.
     */
    private getModelForTable(table);
    /**
     * Generate contents for the basic data types.
     * @param {Table} table - source
     * @return {string} generated content.
     */
    private getBasicDataTypes(table);
    /**
     * Returns the string version of the sequelize type.
     * @param {DataType} type source
     * @return {string} sequelize type
     */
    private getType(type);
    /**
     * Generate association methods for types.
     * @param {Table} table source
     * @return {string} - generated content
     */
    private getRelations(table);
}
