import { Schema, Table } from '../../../commons/types';
/**
 * Class which implements the logic for generating valid sequelize repositories.
 *
 * @export
 * @class SequelizeRepositoryGenerator
 */
export default class SequelizeRepositoryGenerator {
    /**
     * Generate repositories for a given schema.
     *
     * @param {Schema} schema - api schema
     * @return {{name: string, content: string}[]}
     */
    getRepositories(schema: Schema): {
        name: string;
        content: string;
    }[];
    /**
     * Generate repository for a given table.
     *
     * @param {Table} table - schema for table
     * @return {{name: string, content: string}}
     */
    getRepositoryForTable(table: Table): string;
    /**
     * Generate repositories factory.
     *
     * @param {Schema} schema - api schema
     * @return {{name: string, content: string}}
     */
    getRepositoryFactory(schema: Schema): {
        name: string;
        content: string;
    };
}
