"use strict";
var _this = this;
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var logger_1 = require("../../commons/logger");
var chalk = require("chalk");
var inquirer = require("inquirer");
var databaseTypeTrack = require("../inputs/database/databaseType");
var RamlFileOperations_1 = require("../../fileOperations/RamlFileOperations");
exports.questions = [
    {
        name: 'output',
        type: 'input',
        message: 'Raml output directory:',
        default: 'raml',
    },
    {
        name: 'name',
        type: 'input',
        message: 'Application name:',
    },
    {
        name: 'version',
        type: 'input',
        message: 'Version:',
    },
    {
        name: 'url',
        type: 'input',
        message: 'Base URL:',
    },
];
exports.handler = function (data) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
    var _this = this;
    var ramlFileOperations, schemaInfo;
    return tslib_1.__generator(this, function (_a) {
        ramlFileOperations = new RamlFileOperations_1.default(data.output);
        return [2 /*return*/, ramlFileOperations.createDirectoryStructure()
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('reading database schema');
                    return [2 /*return*/, inquirer.prompt(databaseTypeTrack.questions).then(databaseTypeTrack.handler)];
                });
            }); })
                .then(function (schema) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    schemaInfo = schema;
                    logger_1.default.info('generating raml data types');
                    return [2 /*return*/, ramlFileOperations.generateSchemaTypeFiles(schemaInfo)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    console.log(chalk.green('DataType files were created for the api spec.'));
                    return [2 /*return*/, ramlFileOperations.generateSchemaTypeFiles(schemaInfo)];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, ramlFileOperations.generateSchemaExampleFiles(schemaInfo)];
            }); }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('generating example files');
                    return [2 /*return*/, ramlFileOperations.generateSchemaExamplesFilesFromCache()];
                });
            }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    console.log(chalk.green('Example response were created for the api spec.'));
                    return [2 /*return*/];
                });
            }); }).then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () { return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, ramlFileOperations.generateSchemaApiFiles(schemaInfo, data)];
            }); }); })
                .then(function () { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.info('generating the api spec');
                    console.log(chalk.green('Api spec has been created.'));
                    return [2 /*return*/, Promise.resolve(true)];
                });
            }); })
                .catch(function (e) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
                return tslib_1.__generator(this, function (_a) {
                    logger_1.default.error(e.message);
                    return [2 /*return*/, Promise.reject(e)];
                });
            }); })];
    });
}); };
